<?php

    /**
     * The admin-specific functionality of the plugin.
     *
     *
     * @package    Trackboxx
     * @subpackage Trackboxx/admin
     */
    class Trackboxx_Admin {
        /**
         * The ID of this plugin.
         *
         * @since    1.0.0
         * @access   private
         * @var      string $plugin_name The ID of this plugin.
         */
        private $plugin_name;
        /**
         * The version of this plugin.
         *
         * @since    1.0.0
         * @access   private
         * @var      string $version The current version of this plugin.
         */
        private $version;

        /**
         * Initialize the class and set its properties.
         *
         * @param string $plugin_name The name of this plugin.
         * @param string $version     The version of this plugin.
         *
         * @since    1.0.0
         */
        public function __construct($plugin_name, $version) {
            $this->plugin_name = $plugin_name;
            $this->version = $version;
        }

        /**
         * Register the stylesheets for the admin area.
         *
         * @since    1.0.0
         */
        public function enqueue_styles() {
            wp_enqueue_style(
                $this->plugin_name,
                plugin_dir_url(__FILE__) . 'css/trackboxx-admin.css',
                [],
                $this->version,
                'all'
            );
        }

        /**
         * Render plugin settings page.
         *
         * @since    1.0.0
         */
        public function option_page() {
            ?>
            <div class="wrap option-page">
                <h2><?php echo __('Settings', 'trackboxx') ?></h2>

                <form action="options.php" method="POST">
                    <?php
                        settings_fields('trackboxx');
                        do_settings_sections('trackboxx_settings');
                        submit_button();
                    ?>
                </form>
            </div>
            <?php
        }

        /**
         * Register plugin settings using Settings API.
         *
         * @since    1.0.0
         */
        public function option_settings() {
            register_setting('trackboxx', 'trackboxx_tracking_id');
            register_setting('trackboxx', 'trackboxx_public_url');

            add_settings_section('trackboxx_section', '', '', 'trackboxx_settings');

            add_settings_field(
                'trackboxx_tracking_id',
                __('Trackboxx Website Tracking ID', 'trackboxx'),
                [$this, "render_field"],
                'trackboxx_settings',
                'trackboxx_section',
                [
                    'option_name' => 'trackboxx_tracking_id',
                    "description" => __("<p>To get your tracking ID, go here “https://app.trackboxx.com/”, log into your account, click on the Settings icon on the top right of the page, click on “Sites”, then click on “Get Tracking Code”. At the bottom of the code there is an ID like “TB-XXXXXXX”, this is your website tracking id.</p>", "trackboxx"),
                ]
            );
            add_settings_field(
                'trackboxx_public_url',
                __('Trackboxx Public URL', 'trackboxx'),
                [$this, "render_field"],
                'trackboxx_settings',
                'trackboxx_section',
                [
                    'option_name' => 'trackboxx_public_url',
                    "description" => __("<p>If you want to see your dashboard directly inside WordPress, you need to create a Public URL.</p><p>To get your website public URL, go here “https://app.trackboxx.com/”, log into your account, click on the Settings icon on the top right of the page, click on “Sites”, then click on the three dots on the right of your website and click on “Public URL”, then click on “Copy to clipboard” to copy the public url.</p>", "trackboxx"),
                ]
            );
            add_settings_field(
                'trackboxx_optout_text',
                __('Trackboxx Optout', 'trackboxx'),
                [$this, "render_textarea_field"],
                'trackboxx_settings',
                'trackboxx_section',
                [
                    'option_name' => 'trackboxx_optout_text',
                    "description" => __("<p>This is the code you need to enter to show a checkbox so that the user can activate or deactivate the Trackboxx tracking on your website.</p>", "trackboxx"),
                ]
            );
        }

        /**
         * Render settings field.
         *
         * @since    1.0.0
         */
        public function render_textarea_field($args) {
            $option_name = $args['option_name'];
            $val = get_option($option_name);

            $tbTrackingId = get_option('trackboxx_tracking_id');
            $tbTrackingId = $tbTrackingId['input'] ?? 'TB-XXXXXXX';

                $val = $val['input'] ?? '<label class="tb-switch">
  <input type="checkbox" data-domain="'.$tbTrackingId.'" id="tbTrackingAllowed" value="true"/>
  <span class="tb-slider tb-round"></span>
</label>
<span>Tracking erlauben</span>
<script type="text/javascript">
    function tbInitTrackingCheckBox(id) {
        var checkBox = document.getElementById(id);
        checkBox.checked = trackboxxHelper.trackingEnabled();
        checkBox.onclick = function () {
            this.checked ? trackboxxHelper.enableTracking() : trackboxxHelper.enableTracking(\'no\');
        };
    }
    document.addEventListener("tbScriptLoaded", function () {
        tbInitTrackingCheckBox(\'tbTrackingAllowed\');
    });  
</script>';
            ?>
            <textarea readonly name="<?php echo $option_name ?>[input]"/><?php echo esc_attr($val) ?></textarea>
            <?php echo $args["description"] ?>
            <?php
        }

        /**
         * Render settings field.
         *
         * @since    1.0.0
         */
        public function render_field($args) {
            $option_name = $args['option_name'];
            $val = get_option($option_name);
            $val = $val['input'] ?? null;
            ?>
            <input type="text" name="<?php echo $option_name ?>[input]" value="<?php echo esc_attr($val) ?>"/>
            <?php echo $args["description"] ?>
            <?php
        }

        /**
         * Render plugin dashboard page.
         *
         * @since    1.0.0
         */
        public function dashboard_page() {
            global $wp_version;
            $sanitized_wp_version = sanitize_title($wp_version);
            $url = get_option("trackboxx_public_url");
            ?>
            <div class="wrap">
                <h2><?php echo __('Dashboard', 'trackboxx') ?></h2>
                <?php if (isset($url["input"]) && $url["input"]) : ?>
                    <div class="trackboxx-dashboard__wrapper" id="trackboxx-dashboard__wrapper">
                        <iframe id="trackboxx-dashboard-frame" class="trackboxx-dashboard" src="<?php echo $url["input"] ?>?hh=true&hf=true&wp=<?php echo $sanitized_wp_version; ?>" height="100%"></iframe>
                        <script>
                            window.onmessage = (e) => {
                              if (e.data.hasOwnProperty("frameHeight")) {
                                document.getElementById("trackboxx-dashboard-frame").style.height = `${e.data.frameHeight}px`;
                              }
                            };
                        </script>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        }

        /**
         * Register pages for the admin area.
         *
         * @since    1.0.0
         */
        public function add_pages() {
            $parent_slug = "trackboxx-options";

            add_menu_page(
                __('Trackboxx', 'trackboxx'),
                __('Trackboxx', 'trackboxx'),
                'manage_options',
                $parent_slug,
                '',
                '',
                110
            );

            add_submenu_page(
                $parent_slug,
                __('Dashboard', 'trackboxx'),
                __('Dashboard', 'trackboxx'),
                "manage_options",
                "trackboxx_dashboard",
                [$this, "dashboard_page"],
                10
            );

            add_submenu_page(
                $parent_slug,
                __('Settings', 'trackboxx'),
                __('Settings', 'trackboxx'),
                "manage_options",
                "trackboxx_settings",
                [$this, "option_page"],
                20
            );
            
            remove_submenu_page( $parent_slug, $parent_slug );
        }
    }
